==> Mudlib-CD.00.28.tar.gz: lib/std/potion.c <==
/*
 * /std/potion.c
 *
 * This is the standard object used for any form of potion.
 *
 * It works much the same way as herb.c.
 * Potions are quaffed btw ;-)
 *
 * /Nick
 */
#pragma save_binary

inherit "/std/object";
inherit "/lib/herb_support";

#include <cmdparse.h>
#include <composite.h>
#include <macros.h>
#include <stdproperties.h>

int	magic_resistance;	/* How strong is the resistance against magic */
string	smell_msg,
	taste_msg;
object *gFail;

public void
create_potion()
{
    ::create_object();
    set_name("potion");
}

public nomask void
create_object()
{
    smell_msg = "The potion seems without smell.\n";
    taste_msg = "The potion is tasteless.\n";
    create_potion();
}

public nomask void
reset_object() { this_object()->reset_potion(); }

void
init()
{
    ::init();

    add_action("drink_it", "quaff"); /* Use the same routines */
    add_action("drink_it", "taste");
    add_action("drink_it", "smell");
}

void
consume_text(object *arr, string vb)
{
    say(QCTNAME(this_player()) + " " + vb + "s " + COMPOSITE_DEAD(arr) + ".\n");
}

/*
 * Function name: drink_it
 * Description:   Drinks the objects described as parameter to 'drink'.
 *                It uses command parsing to find which objects to drink.
 * Arguments:     str: The trailing command after 'drink ...'
 * Returns:       True if command successful
 */
public int
drink_it(string str)
{
    int i;
    object *a;
    string vb;

    if (this_player()->query_prop(TEMP_STDDRINK_CHECKED))
        return 0;

    gFail = ({});
    vb = query_verb();

    notify_fail(capitalize(vb) + " what?\n");  /* access failure */

    if (!str)
        return 0;
    a = CMDPARSE_ONE_ITEM(str, "drink_one_thing", "drink_access");
    if (sizeof(a) > 0)
    {
        consume_text(a, vb);
        for (i = 0; i < sizeof(a); i++)
            a[i]->destruct_object();
        return 1;
    }
    else
    {
        call_out("tp_remove_temp", 1, this_player());
        this_player()->add_prop(TEMP_STDPOTION_CHECKED, 1);
        if (sizeof(gFail))
            notify_fail("@@drink_fail:" + file_name(this_object()));
        return 0;
    }
}

void
tp_remove_temp(object tp)
{
    tp->remove_prop(TEMP_STDPOTION_CHECKED);
    remove_call_out("tp_remove_temp");
}


int
drink_access(object ob)
{
    if ((environment(ob) == this_player()) &&
        (function_exists("create_object", ob) == "/std/potion") &&
        (ob->short()))
        return 1;
    else
        return 0;
}

string
drink_fail()
{
    string str;

    str = "You try to " + query_verb() + " "+ COMPOSITE_DEAD(gFail) +
	" but fail.\n";
    say(QCTNAME(this_player()) + " tries to " + query_verb() + " " +
	QCOMPDEAD + " but fails.\n");
    tp_remove_temp(this_player());
    return str;
}

int
drink_one_thing(object ob)
{
    string vb;

    if ((vb = query_verb()) == "quaff")
    {
	if (!this_player()->drink_soft(ob->query_soft_amount()))
	{
	    write("The " + capitalize(ob->short()) + " is too much for you.\n");
	    gFail += ({ ob });
	    return 0;
	}
	return 1;
    }

    if (vb == "taste")
	this_player()->catch_msg(taste_msg);
    else
	this_player()->catch_msg(smell_msg);
    return 1;
}

void
destruct_object()
{
    do_herb_effects();
    call_out("remove_object", 1);
}

/*
 * Function name: set_magic_res
 * Description:   Set how resistance this potion is agains magic / how easy it
 *		  is to dispel it.
 * Arguments:     resistance - the resistance
 */
void set_magic_res(int resistance) { magic_resistance = resistance; }

/*
 * Function name: query_magic_resistance
 * Description:   Query the magic resistance
 * Returns:       How resistive the potion is
 */
int
query_magic_res(string prop)
{ 
    if (prop == MAGIC_I_RES_MAGIC)
	return magic_resistance;
    else
	return 0;
}

/*
 * Function name: dispel_magic
 * Description:   Function called by a dispel spell
 * Argument:	  magic - How strong the dispel is
 * Returns:	  0 - No dispelling, 1 - Object dispelled
 */
int
dispel_magic(int magic)
{
    object env;

    if (magic < query_magic_res(MAGIC_I_RES_MAGIC))
	return 0;

    if (living(env = environment(this_object())))
    {
	tell_room(environment(env), "The " + QSHORT(this_object()) +
	    " held by " + QTNAME(env) + " glows white and explodes!\n", env);
	env->catch_msg("The " + QSHORT(this_object()) + " that you hold " +
	    " glows white and explodes!\n");
    } else if (env->query_prop(ROOM_I_IS))
 	tell_room(env, "The " + QSHORT(this_object()) +
	    " glows white and explodes!\n");

    return 1;
}

/*
 * Function name: set_potion_taste
 * Descirption:	  Set the message when player tastes a potion
 * Arguments:	  mess - The message that should be sent to the player
 */
void set_potion_taste(string mess) { taste_msg = mess; }

/*
 * Function name: query_potion_taste
 * Description:   Query the message when tasting the potion
 * Returns:	  The message as set (may be VBFC)
 */
string query_potion_tase() { return taste_msg; }

/*
 * Function name: set_potion_smell
 * Description:   Set the message player will get when smelling on a potion
 * Arguments:	  mess - The message
 */
void set_potion_smell(string mess) { smell_msg = mess; }

/*
 * Function name: query_potion_smell
 * Description:	  Query the message player will get while smelling the potion
 * Returns:	  The message as set (may be VBFC)
 */
string query_potion_smell() { return smell_msg; }

==> Mudlib-CD.00.30.tar.gz: lib/std/potion.c <==
/*
 * /std/potion.c
 *
 * This is the standard object used for any form of potion.
 *
 * It works much the same way as herb.c.
 * Potions are quaffed btw ;-)
 *
 * /Nick
 */
#pragma save_binary

inherit "/std/object";
inherit "/lib/herb_support";

#include <cmdparse.h>
#include <composite.h>
#include <macros.h>
#include <stdproperties.h>

int	magic_resistance;	/* How strong is the resistance against magic */
string	smell_msg,
	taste_msg;
object *gFail;

public void
create_potion()
{
    ::create_object();
    set_name("potion");
}

public nomask void
create_object()
{
    smell_msg = "The potion seems without smell.\n";
    taste_msg = "The potion is tasteless.\n";
    create_potion();
}

public nomask void
reset_object() { this_object()->reset_potion(); }

void
init()
{
    ::init();

    add_action("drink_it", "quaff"); /* Use the same routines */
    add_action("drink_it", "taste");
    add_action("drink_it", "smell");
}

void
consume_text(object *arr, string vb)
{
    say(QCTNAME(this_player()) + " " + vb + "s " + COMPOSITE_DEAD(arr) + ".\n");
}

/*
 * Function name: drink_it
 * Description:   Drinks the objects described as parameter to 'drink'.
 *                It uses command parsing to find which objects to drink.
 * Arguments:     str: The trailing command after 'drink ...'
 * Returns:       True if command successful
 */
public int
drink_it(string str)
{
    int i;
    object *a;
    string vb;

    if (this_player()->query_prop(TEMP_STDDRINK_CHECKED))
        return 0;

    gFail = ({});
    vb = query_verb();

    notify_fail(capitalize(vb) + " what?\n");  /* access failure */

    if (!str)
        return 0;
    a = CMDPARSE_ONE_ITEM(str, "drink_one_thing", "drink_access");
    if (sizeof(a) > 0)
    {
        consume_text(a, vb);
        for (i = 0; i < sizeof(a); i++)
            a[i]->destruct_object();
        return 1;
    }
    else
    {
        call_out("tp_remove_temp", 1, this_player());
        this_player()->add_prop(TEMP_STDPOTION_CHECKED, 1);
        if (sizeof(gFail))
            notify_fail("@@drink_fail:" + file_name(this_object()));
        return 0;
    }
}

void
tp_remove_temp(object tp)
{
    tp->remove_prop(TEMP_STDPOTION_CHECKED);
    remove_call_out("tp_remove_temp");
}


int
drink_access(object ob)
{
    if ((environment(ob) == this_player()) &&
        (function_exists("create_object", ob) == "/std/potion") &&
        (ob->short()))
        return 1;
    else
        return 0;
}

string
drink_fail()
{
    string str;

    str = "You try to " + query_verb() + " "+ COMPOSITE_DEAD(gFail) +
	" but fail.\n";
    say(QCTNAME(this_player()) + " tries to " + query_verb() + " " +
	QCOMPDEAD + " but fails.\n");
    tp_remove_temp(this_player());
    return str;
}

int
drink_one_thing(object ob)
{
    string vb;

    if ((vb = query_verb()) == "quaff")
    {
	if (!this_player()->drink_soft(ob->query_soft_amount()))
	{
	    write("The " + capitalize(ob->short()) + " is too much for you.\n");
	    gFail += ({ ob });
	    return 0;
	}
	return 1;
    }

    if (vb == "taste")
	this_player()->catch_msg(taste_msg);
    else
	this_player()->catch_msg(smell_msg);
    return 1;
}

void
destruct_object()
{
    do_herb_effects();
    call_out("remove_object", 1);
}

/*
 * Function name: set_magic_res
 * Description:   Set how resistance this potion is agains magic / how easy it
 *		  is to dispel it.
 * Arguments:     resistance - the resistance
 */
void set_magic_res(int resistance) { magic_resistance = resistance; }

/*
 * Function name: query_magic_resistance
 * Description:   Query the magic resistance
 * Returns:       How resistive the potion is
 */
int
query_magic_res(string prop)
{ 
    if (prop == MAGIC_I_RES_MAGIC)
	return magic_resistance;
    else
	return 0;
}

/*
 * Function name: dispel_magic
 * Description:   Function called by a dispel spell
 * Argument:	  magic - How strong the dispel is
 * Returns:	  0 - No dispelling, 1 - Object dispelled
 */
int
dispel_magic(int magic)
{
    object env;

    if (magic < query_magic_res(MAGIC_I_RES_MAGIC))
	return 0;

    if (living(env = environment(this_object())))
    {
	tell_room(environment(env), "The " + QSHORT(this_object()) +
	    " held by " + QTNAME(env) + " glows white and explodes!\n", env);
	env->catch_msg("The " + QSHORT(this_object()) + " that you hold " +
	    " glows white and explodes!\n");
    } else if (env->query_prop(ROOM_I_IS))
 	tell_room(env, "The " + QSHORT(this_object()) +
	    " glows white and explodes!\n");

    return 1;
}

/*
 * Function name: set_potion_taste
 * Descirption:	  Set the message when player tastes a potion
 * Arguments:	  mess - The message that should be sent to the player
 */
void set_potion_taste(string mess) { taste_msg = mess; }

/*
 * Function name: query_potion_taste
 * Description:   Query the message when tasting the potion
 * Returns:	  The message as set (may be VBFC)
 */
string query_potion_taste() { return taste_msg; }

/*
 * Function name: set_potion_smell
 * Description:   Set the message player will get when smelling on a potion
 * Arguments:	  mess - The message
 */
void set_potion_smell(string mess) { smell_msg = mess; }

/*
 * Function name: query_potion_smell
 * Description:	  Query the message player will get while smelling the potion
 * Returns:	  The message as set (may be VBFC)
 */
string query_potion_smell() { return smell_msg; }
